==> deepin-update-ui_1.0.6.tar.xz: BUILD/src/dcc-update-plugin/translations/update_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Darrera comprovació: </translation>
    </message>
</context>
<context>
    <name>NoActive</name>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>El sistema no està activat i no s&apos;ha pogut connectar per actualitzar-ne els serveis.</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Si sortiu del programa beta, ja no rebreu actualitzacions beta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Save the display settings?</source>
        <translation type="unfinished">Voleu desar els paràmetres de la pantalla?</translation>
    </message>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation type="unfinished">La configuració es revertirà d&apos;aquí a %1 s.</translation>
    </message>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation>La configuració es revertirà d&apos;aquí a %1 s.</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation type="unfinished">Reveteix</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Desa</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Mostra&apos;n els detalls</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Actualitzacions:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Data de publicació:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>CAP</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>BAIXA</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MITJANA</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ALTA</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>CRÍTICA</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>risc crític</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>risc alt</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>risc mitjà</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>risc baix</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconegut</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Aquesta actualització corregeix</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>vulnerabilitats</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>vulnerabilitat</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 de %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>,</translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>per a més detalls, visiteu</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Es comprova si hi ha actualitzacions. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>El sistema està actualitzat.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Ha fallat baixar les actualitzacions. Primer allibereu %1 d&apos;espai al disc.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Error de dependència, no s&apos;han pogut detectar les actualitzacions</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Comproveu la xarxa i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Ha fallat baixar les actualitzacions. Comproveu la xarxa i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No es pot fer una còpia de seguretat del sistema. Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Espai de disc insuficient</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error de DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Falta un fitxer</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>La connexió del servei és anormal. Comproveu la xarxa i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>La configuració de l&apos;origen del repositori no és vàlida. Comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Torna-ho a comprovar</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Canvi intel·ligent de rèplica</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Tipus d&apos;actualització</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Actualitzacions de funcions</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Ofereix una actualització acumulativa que inclou funcions noves, actualitzacions de qualitat i actualitzacions de seguretat.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualitzacions de seguretat</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Ofereix actualitzacions de seguretat.</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Actualitzacions de tercers</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Ofereix actualitzacions per a fonts de repositoris addicionals.</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Límit de velocitat</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Configuració del límit</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Baixa-les automàticament.</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Si n&apos;activeu la baixada automàtica, les actualitzacions es baixaran automàticament quan hi hagi connexió a Internet.</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Baixa-les durant l&apos;estat inactiu</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Comença a</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Acaba a</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Configuració avançada</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Notificació d&apos;actualitzacions</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Neteja la cau de paquets</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Historial d&apos;actualitzacions</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Uniu-vos al canal de proves internes</translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates</source>
        <translation>Uniu-vos al canal de proves internes per rebre les darreres actualitzacions del Deepin.</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Feu clic aquí per completar la sol·licitud.</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Actualitzacions del sistema</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>S&apos;han corregit alguns errors coneguts i vulnerabilitats de seguretat.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualitzacions de seguretat</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Repositoris de tercers</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Actualització del sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Actualització i millora del sistema</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Configuració de l&apos;actualització</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>S&apos;instal·la</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>S&apos;ha completat la baixada de l&apos;actualització.</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Instal·la les actualitzacions</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Mida de l&apos;actualització:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation> Ha fallat la baixada de l&apos;actualització.</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Es baixen les actualitzacions...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Es baixa</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Estableix la configuració de l&apos;actualització, de les actualitzacions de seguretat, la baixada automàtica i la notificació de les actualitzacions.</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Reinicia ara</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>S&apos;instal·len actualitzacions...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Reintenta</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Continua l&apos;actualització</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Actualitzacions disponibles</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Ha fallat la instal·lació de l&apos;actualització.</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Per assegurar el bon funcionament del sistema i les aplicacions, reinicieu l&apos;ordinador després de l&apos;actualització.</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Còpia de seguretat en curs...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Còpia de seguretat en curs</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Ha fallat la còpia de seguretat.</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Actualització instal·lada correctament</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Torna a fer una còpia de seguretat</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dcc-update-plugin/translations/update_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Darrera comprovació: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Si sortiu del programa beta, ja no rebreu actualitzacions beta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>UpdateDisable</name>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Les actualitzacions del sistema estan desactivades. Poseu-vos en contacte amb l&apos;administrador per obtenir ajuda.</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>El sistema no està activat i no s&apos;ha pogut connectar per actualitzar-ne els serveis.</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Historial d&apos;actualitzacions</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>No hi ha historial d&apos;actualitzacions.</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Actualitzacions del sistema</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualitzacions de seguretat</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Ofereix una actualització acumulativa que inclou funcions noves, actualitzacions de qualitat i de seguretat.</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Ofereix actualitzacions de seguretat.</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Data de la instal·lació:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Mostra&apos;n els detalls</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Actualitzacions:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Data de publicació:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>CAP</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>BAIXA</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MITJANA</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ALTA</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>CRÍTICA</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>risc crític</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>risc alt</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>risc mitjà</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>risc baix</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconegut</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Aquesta actualització corregeix</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>vulnerabilitats</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>vulnerabilitat</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 de %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>,</translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>per a més detalls, visiteu</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Es comprova si hi ha actualitzacions. Espereu, si us plau...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>El sistema està actualitzat.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Ha fallat baixar les actualitzacions. Primer allibereu %1 d&apos;espai al disc.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Error de dependència, no s&apos;han pogut detectar les actualitzacions</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Comproveu la xarxa i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Ha fallat baixar les actualitzacions. Comproveu la xarxa i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No es pot fer una còpia de seguretat del sistema. Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Espai de disc insuficient</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error de DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Falta un fitxer</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>La connexió del servei és anormal. Comproveu la xarxa i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>La configuració de l&apos;origen del repositori no és vàlida. Comproveu-ho i torneu-ho a provar.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Torna-ho a comprovar</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Política de privadesa</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Per usar aquest programari, cal que accepteu la %1 que acompanya les actualitzacions del programari.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Activeu els interruptors a Actualitza el contingut per obtenir-ne una experiència millor.</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Canvi intel·ligent de rèplica</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Tipus d&apos;actualització</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Actualitzacions de funcions</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Ofereix una actualització acumulativa que inclou funcions noves, actualitzacions de qualitat i actualitzacions de seguretat.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualitzacions de seguretat</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Ofereix actualitzacions de seguretat.</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Actualitzacions de tercers</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Ofereix actualitzacions per a fonts de repositoris addicionals.</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Límit de velocitat</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Configuració del límit</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Baixa-les automàticament.</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Si n&apos;activeu la baixada automàtica, les actualitzacions es baixaran automàticament quan hi hagi connexió a Internet.</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Baixa-les durant l&apos;estat inactiu</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Comença a</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Acaba a</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Configuració avançada</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Notificació d&apos;actualitzacions</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Neteja la cau de paquets</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Historial d&apos;actualitzacions</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Uniu-vos al canal de proves internes</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Feu clic aquí per completar la sol·licitud.</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandeix</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>Els usuaris del fòrum de nivell 2 o superior poden unir-se a la prova beta per rebre les últimes actualitzacions.</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Actualitzacions del sistema</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>S&apos;han corregit alguns errors coneguts i vulnerabilitats de seguretat.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Actualitzacions de seguretat</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Repositoris de tercers</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Actualització del sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Actualització i millora del sistema</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Configuració de l&apos;actualització</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>S&apos;instal·la</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>S&apos;ha completat la baixada de l&apos;actualització.</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Instal·la les actualitzacions</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Mida de l&apos;actualització:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation> Ha fallat la baixada de l&apos;actualització.</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Es baixen les actualitzacions...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Es baixa</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Estableix la configuració de l&apos;actualització, de les actualitzacions de seguretat, la baixada automàtica i la notificació de les actualitzacions.</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Reinicia ara</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>S&apos;instal·len actualitzacions...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Reintenta</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Continua l&apos;actualització</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Actualitzacions disponibles</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Ha fallat la instal·lació de l&apos;actualització.</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Per assegurar el bon funcionament del sistema i les aplicacions, reinicieu l&apos;ordinador després de l&apos;actualització.</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Còpia de seguretat en curs...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Còpia de seguretat en curs</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Ha fallat la còpia de seguretat.</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Actualització instal·lada correctament</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si continueu les actualitzacions, no podreu tornar al sistema anterior més tard.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation> Torneu-ho a provar</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Procedeix a l&apos;actualització</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>La capacitat de la bateria és inferior al 60%. Per obtenir actualitzacions correctes, endolleu el dispositiu.</translation>
    </message>
</context>
</TS>
